@@ -1,6 +1,10 @@
 """Mailgun client module."""
+from functools import partial
+
 import requests
 
+from .domain import Domain
+from .ips import IPs
 from .mailing_list import MailingList
 
 
@@ -12,7 +16,10 @@ class MailgunApi(object):  # pylint: disable=too-few-public-methods
         self.api_key = api_key
         self.session = requests.Session()
         # APIs
+        self.ips = IPs(self)
         self.mailing_list = MailingList(self)
+        # Domain APIs
+        self.domain = partial(Domain, self)
 
     def set_api_key(self, api_key):
         """
