@@ -1,8 +1,10 @@
+import functools
 import unittest
 
 import requests
 
 from mailgun.api import MailgunApi
+from mailgun.domain import Domain
 from mailgun.mailing_list import MailingList
 
 
@@ -15,6 +17,14 @@ class MailgunApiTestCase(unittest.TestCase):
         self.assertIsInstance(api.mailing_list, MailingList)
         self.assertIs(api.mailing_list.api, api)
 
+    def test_init_domain(self):
+        api = MailgunApi()
+        self.assertIsInstance(api.domain, functools.partial)
+        domain = api.domain('mydomain.com')
+        self.assertIsInstance(domain, Domain)
+        self.assertIs(domain.api, api)
+        self.assertEqual(domain.name, 'mydomain.com')
+
     def test_set_api_key(self):
         api = MailgunApi()
         api.set_api_key('api-key-xxx')
